maze
================================================================================
This version of PLUMED2 has the maze module implemented.

Install
--------------------------------------------------------------------------------
Enable the compilation of maze by adding the `--enable-modules=maze` to the 
configure command.

Page
--------------------------------------------------------------------------------
See [this link](http://maze-code.github.io) for further information.

Documentation
--------------------------------------------------------------------------------
Run `make doc`; the documentation should be in `user-doc/html/_m_a_z_e.html`.

Author
--------------------------------------------------------------------------------
Jakub Rydzewski (Nicolaus Copernicus University) <jr@fizyka.umk.pl>

Copyright
--------------------------------------------------------------------------------
This program is free software: you can redistribute it and/or modify it under 
the terms of the GNU Lesser General Public License as published by the Free 
Software Foundation, either version 3 of the License, or (at your option) any 
later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY 
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
PARTICULAR PURPOSE.  

See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along 
with this program.  If not, see <http://www.gnu.org/licenses/>.
